@@ -3,6 +3,7 @@ import { ReactElement } from 'react';
 import { locationUtil } from '@grafana/data';
 import { locationService } from '@grafana/runtime';
 import { Button, Modal, Stack } from '@grafana/ui';
+import { Trans } from 'app/core/internationalization';
 
 type Props = {
   onDismiss: () => void;
@@ -25,13 +26,13 @@ export function ConfirmNavigationModal(props: Props): ReactElement {
       </Stack>
       <Modal.ButtonRow>
         <Button onClick={onDismiss} fill="outline" variant="secondary">
-          Cancel
+          <Trans i18nKey="explore.confirm-navigation-modal.cancel">Cancel</Trans>
         </Button>
         <Button type="submit" variant="secondary" onClick={openInNewTab} icon="external-link-alt">
-          Open in new tab
+          <Trans i18nKey="explore.confirm-navigation-modal.open-in-new-tab">Open in new tab</Trans>
         </Button>
         <Button type="submit" variant="primary" onClick={openInCurrentTab} icon="apps">
-          Open
+          <Trans i18nKey="explore.confirm-navigation-modal.open">Open</Trans>
         </Button>
       </Modal.ButtonRow>
     </Modal>
